## Avengers

### Variables

- name = super hero name
- alignment = good or bad character
- gender = male or female
- publisher = name of the comic publisher

Note: There is a deliberate mistake in the data. See the help file in the _Data > Combine_ tab